@@ -1,4 +1,6 @@
-VERSION = (1, 9, 1)
+from __future__ import absolute_import, unicode_literals
+
+VERSION = (1, 9, 2)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -74,8 +76,14 @@ def ensure_completely_loaded(force=False):
     # get_models cache again here. If we don't do this, Django 1.5 chokes on
     # a model validation error (Django 1.4 doesn't exhibit this problem).
     # See Issue #323 on github.
-    loading.cache._get_models_cache.clear()
+    if hasattr(loading, 'cache'):
+        loading.cache._get_models_cache.clear()
 
-    if loading.app_cache_ready():
-        COMPLETELY_LOADED = True
+    if hasattr(loading.app_cache_ready, '__call__'):
+        if loading.app_cache_ready():
+            COMPLETELY_LOADED = True
+    else:
+        # TODO Django 1.7 offers us better ways of handling this, maybe.
+        if loading.app_cache_ready:
+            COMPLETELY_LOADED = True
     return True
