@@ -8,7 +8,7 @@
 #    tagging.tag_model(Page)
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from django import forms
 from django.contrib.admin.widgets import FilteredSelectMultiple
@@ -102,7 +102,7 @@ def tag_model(cls, admin_cls=None, field_name='tags', sort_tags=False,
     sort_tags   Boolean, defaults to False. If set to True, a pre_save
                 handler will be inserted to sort the tag field alphabetically.
                 This is useful in case you want a canonical representation
-                for a tag collection, as when you're presenting a list of
+                for a tag collection, as when yo're presenting a list of
                 tag combinations (e.g. in an admin filter list).
     select_field If True, show a multi select instead of the standard
                 CharField for tag entry.
